# Pre-processing Go-NoGo 

rm(list=ls())

## 1.Load Packages --------------------------------------------------------------

ipak <- function(pkg) {
new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])]
if (length(new.pkg))
install.packages(new.pkg, dependencies = T)
sapply(pkg, require, character.only = T)
}
packages <- c("readr", "dplyr", "tidyverse", "ggplot2", "ggpubr")
ipak(packages)

theme_set(theme_pubr())

## 2.Load data --------------------------------------------------------------

d <- list.files(path = "DATA_RAW/data_exp", pattern = "*.csv", full.names = TRUE) %>% 
  map_df(~read_csv(.x) %>% mutate(condition = as.character(condition),
                                  session = as.character(session))) # Combine data sets into one data set 


## 3. Prep data --------------------------------------------------------------

# DATA GNG task
dat <- subset(d, RUN >= 1) |>
        mutate(id = case_when(participant == "GNG87"~ "GNG84",
                        participant == "GN103"~ "GNG103",
                        participant == "GN100"~ "GNG100",
                        .default = participant),
         P = factor(LW_P),
         target = factor(target_col),
         C = factor(case_when(condition == "CONDIZIONE FS" ~ "FS",
                       condition == "FF" ~ "FS",
                       condition == "fs" ~ "FS",
                       condition == "sd" ~ "SD",
                       condition == "FS" ~ "FS",
                       condition == "CONDIZIONE SD" ~ "SD",
                       condition == "SD" ~ "SD",
                       condition == " SD" ~ "SD",
                       condition == " FS" ~ "FS"
         )),
         S = factor(case_when(session == "SESSIONE 1" ~ 1,
                              session == 1 ~ 1,
                              session == "SESSIONE 2" ~ 2,
                              session == 2 ~ 2)),
         R = factor(RUN),
         B = factor(B),
         rt = target_kb.rt,
         N_1 = ifelse(lag(target) == "go.png", "go.png","nogo.png"),
         N_1_rt = lag(rt),
         resp = target_kb.keys,
         Trial = TRIAL.thisN + 1)|>
  select(id, P, target, C, S, R, B, rt, resp, Trial,N_1,N_1_rt)

str(dat)

# Create Order Variable for session 2 analysis ----------------------
id_SD = subset(dat, C == "SD")|>
  select(id)|>
  unique()
id_FS = subset(dat, C == "FS" & S == 1)|>
  select(id)|>
  unique()

Order = rep("SD_FS",length(id_SD$id))
id_SD = cbind(id_SD, Order)
Order = rep("FS_FS",length(id_FS$id))
id_FS = cbind(id_FS, Order)

order_id = rbind(id_SD,id_FS)

# add data
dat = dat %>%
  left_join(.,order_id, by = "id")


subj_group = unique(dplyr::select(dat, c("id","Order")))
sum(subj_group$Order == "FS_FS", na.rm = T) # 36 tot
sum(subj_group$Order == "SD_FS", na.rm = T) # 43 tot


# Calculate accuracy -----------------------------------------------

dat$acc <- c()
dat$acc<- case_when(dat$target == "nogo.png" & dat$resp == "space" ~ 0,
                    dat$target == "nogo.png" &  is.na(dat$resp) ~ 1,
                    dat$target == "go.png" & dat$resp == "space" ~ 1,
                    dat$target == "go.png" & is.na(dat$resp) ~ 0)

sum(is.na(dat$acc)) #check
str(dat)

  
# save!
go_nogo <- write_csv(dat, file = 'DATA_OUT/go_nogo.csv')

# Clean and Visualize data -----------------------------------------------

## Session 1
dat_clean_1 <- subset(go_nogo, S == 1 &
                        # low ACC
                        id != "GNG38" & id != "GNG59" & id != "GNG102" &
                        # PSQI = 14
                        id != "GNG82" & 
                        # not respect sleep schedule
                        id != "GNG16" & 
                        id != "GNG21" & id != "GNG40" & 
                        id != "GNG46" & id != "GNG51" &
                        id != "GNG52"& id != "GNG58" &
                        id != "GNG65" & id != "GNG72" &
                        id != "GNG75" &  id != "GNG83"&
                        id != "GNG92" & id != "GNG95"&
                        id != "GNG96" & id != "GNG105")

## Session 2
dat_clean_2 <- subset(go_nogo, S == 2 &
                        # low ACC
                        id != "GNG38" & id != "GNG59" & id != "GNG102" &
                        # PSQI = 14
                        id != "GNG82" & 
                        # not respect sleep schedule
                        id != "GNG16" & 
                        id != "GNG21" & id != "GNG40" & 
                        id != "GNG46" & id != "GNG51" &
                        id != "GNG52"& id != "GNG58" &
                        id != "GNG65" & id != "GNG72" &
                        id != "GNG75" &  id != "GNG83"&
                        id != "GNG92" & id != "GNG95"&
                        id != "GNG96" & id != "GNG105" &
                        #spec session 2
                        id != "GNG18" & id != "GNG29" &
                        id != "GNG34" & id != "GNG50")

df_clean <- rbind(dat_clean_1,dat_clean_2)

subset(df_clean, S == 1 & rt > .1)%>%ggplot(aes(x= rt, fill = P))+
  geom_density(alpha = .5)+facet_wrap(Order~target)
subset(df_clean, S == 2 & rt > .1)%>%ggplot(aes(x= rt, fill = P))+
  geom_density(alpha = .5)+facet_wrap(Order~target)

subset(df_clean, S == 1 & rt > .1)%>%group_by(Order, target,P)%>%
  summarise(rt_m = mean(rt),
            rt_sd = sd(rt),
            n = n())
  
